#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <string>
#include <algorithm>

#include <openssl/err.h>

#include "opensslgenericutil.h"

namespace AuthN {
namespace OpenSSL {

  void trim_blank(std::string& str) {
    // Trim the blank in the begining and end of a string
    std::string::size_type pos1, pos2;
    std::string blanks(" \t");
    pos1 = str.find_first_not_of(blanks);
    pos2 = str.find_last_not_of(blanks);
    str = str.substr(pos1, pos2-pos1+1);
  }

  std::string upper_string(const std::string& str) {
    std::string upper;
    std::transform(str.begin(), str.end(), std::back_inserter(upper), toupper);
    return upper;
  }

  std::string lower_string(const std::string& str) {
    std::string lower;
    std::transform(str.begin(), str.end(), std::back_inserter(lower), tolower);
    return lower;
  }

  std::string GetOpenSSLError(int err) {
    std::string errstr;
    unsigned long errors;
    char errors_buf[256] = { 0 };
    if(err == 0) {
      errors = ERR_get_error();
    } else {
      errors = err;
    };
    while(errors != 0){
      ERR_error_string_n(errors,errors_buf,sizeof(errors_buf));
      errors_buf[sizeof(errors_buf)-1] = 0;
      errstr += errors_buf;
      errstr += "\n";
      errors = ERR_get_error();
    };
    return errstr;
  }

}
}


